# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: deepproto/proto/tracepoint/v1/tracepoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from deepproto.proto.common.v1 import common_pb2 as deepproto_dot_proto_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.deepproto/proto/tracepoint/v1/tracepoint.proto\x12\x1d\x64\x65\x65pproto.proto.tracepoint.v1\x1a&deepproto/proto/common/v1/common.proto\"\x80\x02\n\x10TracePointConfig\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x13\n\x0bline_number\x18\x03 \x01(\r\x12G\n\x04\x61rgs\x18\x04 \x03(\x0b\x32\x39.deepproto.proto.tracepoint.v1.TracePointConfig.ArgsEntry\x12\x0f\n\x07watches\x18\x05 \x03(\t\x12\x36\n\ttargeting\x18\x06 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\x1a+\n\tArgsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"g\n\nVariableID\x12\n\n\x02ID\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tmodifiers\x18\x03 \x03(\t\x12\x1a\n\roriginal_name\x18\x04 \x01(\tH\x00\x88\x01\x01\x42\x10\n\x0e_original_name\"\x98\x01\n\x08Variable\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\x12\x0c\n\x04hash\x18\x03 \x01(\t\x12;\n\x08\x63hildren\x18\x04 \x03(\x0b\x32).deepproto.proto.tracepoint.v1.VariableID\x12\x16\n\ttruncated\x18\x05 \x01(\x08H\x00\x88\x01\x01\x42\x0c\n\n_truncated\"\x93\x04\n\nStackFrame\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12\x13\n\x0bmethod_name\x18\x02 \x01(\t\x12\x13\n\x0bline_number\x18\x03 \x01(\r\x12\x17\n\nclass_name\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x15\n\x08is_async\x18\x05 \x01(\x08H\x01\x88\x01\x01\x12\x1a\n\rcolumn_number\x18\x06 \x01(\rH\x02\x88\x01\x01\x12!\n\x14transpiled_file_name\x18\x07 \x01(\tH\x03\x88\x01\x01\x12#\n\x16transpiled_line_number\x18\x08 \x01(\rH\x04\x88\x01\x01\x12%\n\x18transpiled_column_number\x18\t \x01(\rH\x05\x88\x01\x01\x12<\n\tvariables\x18\n \x03(\x0b\x32).deepproto.proto.tracepoint.v1.VariableID\x12\x16\n\tapp_frame\x18\x0b \x01(\x08H\x06\x88\x01\x01\x12\x19\n\x0cnative_frame\x18\x0c \x01(\x08H\x07\x88\x01\x01\x42\r\n\x0b_class_nameB\x0b\n\t_is_asyncB\x10\n\x0e_column_numberB\x17\n\x15_transpiled_file_nameB\x19\n\x17_transpiled_line_numberB\x1b\n\x19_transpiled_column_numberB\x0c\n\n_app_frameB\x0f\n\r_native_frame\"\x85\x01\n\x0bWatchResult\x12\x12\n\nexpression\x18\x01 \x01(\t\x12@\n\x0bgood_result\x18\x02 \x01(\x0b\x32).deepproto.proto.tracepoint.v1.VariableIDH\x00\x12\x16\n\x0c\x65rror_result\x18\x03 \x01(\tH\x00\x42\x08\n\x06result\"\x94\x04\n\x08Snapshot\x12\n\n\x02ID\x18\x01 \x01(\x0c\x12\x43\n\ntracepoint\x18\x02 \x01(\x0b\x32/.deepproto.proto.tracepoint.v1.TracePointConfig\x12J\n\nvar_lookup\x18\x03 \x03(\x0b\x32\x36.deepproto.proto.tracepoint.v1.Snapshot.VarLookupEntry\x12\x10\n\x08ts_nanos\x18\x04 \x01(\x06\x12\x39\n\x06\x66rames\x18\x05 \x03(\x0b\x32).deepproto.proto.tracepoint.v1.StackFrame\x12;\n\x07watches\x18\x06 \x03(\x0b\x32*.deepproto.proto.tracepoint.v1.WatchResult\x12\x37\n\nattributes\x18\x07 \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\x12\x16\n\x0e\x64uration_nanos\x18\x08 \x01(\x04\x12\x35\n\x08resource\x18\t \x03(\x0b\x32#.deepproto.proto.common.v1.KeyValue\x1aY\n\x0eVarLookupEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x36\n\x05value\x18\x02 \x01(\x0b\x32\'.deepproto.proto.tracepoint.v1.Variable:\x02\x38\x01\"\x12\n\x10SnapshotResponse2u\n\x0fSnapshotService\x12\x62\n\x04send\x12\'.deepproto.proto.tracepoint.v1.Snapshot\x1a/.deepproto.proto.tracepoint.v1.SnapshotResponse\"\x00\x42\\\n&com.intergral.deep.proto.tracepoint.v1P\x01Z0github.com/intergral/go-deep-proto/tracepoint/v1b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'deepproto.proto.tracepoint.v1.tracepoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n&com.intergral.deep.proto.tracepoint.v1P\001Z0github.com/intergral/go-deep-proto/tracepoint/v1'
  _TRACEPOINTCONFIG_ARGSENTRY._options = None
  _TRACEPOINTCONFIG_ARGSENTRY._serialized_options = b'8\001'
  _SNAPSHOT_VARLOOKUPENTRY._options = None
  _SNAPSHOT_VARLOOKUPENTRY._serialized_options = b'8\001'
  _TRACEPOINTCONFIG._serialized_start=122
  _TRACEPOINTCONFIG._serialized_end=378
  _TRACEPOINTCONFIG_ARGSENTRY._serialized_start=335
  _TRACEPOINTCONFIG_ARGSENTRY._serialized_end=378
  _VARIABLEID._serialized_start=380
  _VARIABLEID._serialized_end=483
  _VARIABLE._serialized_start=486
  _VARIABLE._serialized_end=638
  _STACKFRAME._serialized_start=641
  _STACKFRAME._serialized_end=1172
  _WATCHRESULT._serialized_start=1175
  _WATCHRESULT._serialized_end=1308
  _SNAPSHOT._serialized_start=1311
  _SNAPSHOT._serialized_end=1843
  _SNAPSHOT_VARLOOKUPENTRY._serialized_start=1754
  _SNAPSHOT_VARLOOKUPENTRY._serialized_end=1843
  _SNAPSHOTRESPONSE._serialized_start=1845
  _SNAPSHOTRESPONSE._serialized_end=1863
  _SNAPSHOTSERVICE._serialized_start=1865
  _SNAPSHOTSERVICE._serialized_end=1982
# @@protoc_insertion_point(module_scope)
